@@ -36,18 +36,17 @@ from neutron_lib.api.definitions import expose_port_forwarding_in_fip
 from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import extra_dhcp_opt
 from neutron_lib.api.definitions import extraroute
+from neutron_lib.api.definitions import extraroute_atomic
 from neutron_lib.api.definitions import filter_validation
 from neutron_lib.api.definitions import fip64
+from neutron_lib.api.definitions import fip_pf_description
 from neutron_lib.api.definitions import fip_port_details
-from neutron_lib.api.definitions import firewall
 from neutron_lib.api.definitions import firewall_v2
-from neutron_lib.api.definitions import firewallrouterinsertion
 from neutron_lib.api.definitions import flavors
 from neutron_lib.api.definitions import floating_ip_port_forwarding
 from neutron_lib.api.definitions import floatingip_autodelete_internal
 from neutron_lib.api.definitions import floatingip_pools
 from neutron_lib.api.definitions import flowclassifier
-from neutron_lib.api.definitions import interconnection
 from neutron_lib.api.definitions import ip_allocation
 from neutron_lib.api.definitions import ip_substring_port_filtering
 from neutron_lib.api.definitions import l2_adjacency
@@ -86,6 +85,7 @@ from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
 from neutron_lib.api.definitions import rbac_security_groups
 from neutron_lib.api.definitions import revisionifmatch
+from neutron_lib.api.definitions import router_admin_state_down_before_update
 from neutron_lib.api.definitions import router_availability_zone
 from neutron_lib.api.definitions import router_interface_fip
 from neutron_lib.api.definitions import routerservicetype
@@ -97,6 +97,7 @@ from neutron_lib.api.definitions import sfc
 from neutron_lib.api.definitions import sort_key_validation
 from neutron_lib.api.definitions import sorting
 from neutron_lib.api.definitions import standard_attr_segment
+from neutron_lib.api.definitions import stateful_security_group
 from neutron_lib.api.definitions import subnet
 from neutron_lib.api.definitions import subnet_dns_publish_fixed_ip
 from neutron_lib.api.definitions import subnet_onboard
@@ -141,17 +142,16 @@ _ALL_API_DEFINITIONS = {
     external_net,
     extra_dhcp_opt,
     extraroute,
+    extraroute_atomic,
     filter_validation,
     fip64,
-    firewall,
     firewall_v2,
-    firewallrouterinsertion,
     fip_port_details,
     flavors,
     floating_ip_port_forwarding,
+    fip_pf_description,
     floatingip_autodelete_internal,
     floatingip_pools,
-    interconnection,
     ip_allocation,
     ip_substring_port_filtering,
     l2_adjacency,
@@ -191,6 +191,7 @@ _ALL_API_DEFINITIONS = {
     qos_rules_alias,
     rbac_security_groups,
     revisionifmatch,
+    router_admin_state_down_before_update,
     router_availability_zone,
     router_interface_fip,
     routerservicetype,
@@ -202,6 +203,7 @@ _ALL_API_DEFINITIONS = {
     sort_key_validation,
     sorting,
     standard_attr_segment,
+    stateful_security_group,
     subnet,
     subnet_dns_publish_fixed_ip,
     subnet_onboard,
