@@ -55,7 +55,8 @@ KNOWN_RESOURCES = (
     'ports',
     'routers',
     'subnets',
-    'subnetpools'
+    'subnetpools',
+    'security_groups'
 )
 
 KNOWN_HTTP_ACTIONS = (
@@ -97,10 +98,12 @@ KNOWN_EXTENSIONS = (
     'external-net',
     'extra_dhcp_opt',
     'extraroute',
+    'extraroute-atomic',
     'filter-validation',
     'fip-port-details',
     'flavors',
     'floating-ip-port-forwarding',
+    'floating-ip-port-forwarding-description',
     'floatingip-autodelete-internal',
     'floatingip-pools',
     'ip-substring-filtering',
@@ -167,9 +170,6 @@ KNOWN_EXTENSIONS = (
     # https://opendev.org/openstack/networking-sfc:
     'flow_classifier',
     'sfc',
-
-    # https://opendev.org/openstack/neutron-interconnection:
-    'interconnection',
 )
 
 KNOWN_KEYWORDS = (
